#!/bin/sh

# Copyright (C) 2004-2016 QVidium Technologies, Inc. All rights reserved.

get_elapsed_time() {
    secs=$1
    if [ $secs -lt 60 ] ; then
        ELAPSED_TIME="$secs secs"
    else
        day=$((secs / 86400))
        hr=$((secs / 3600 % 24))
        min=$((secs / 60 % 60))
        ELAPSED_TIME=
        comma=
        [ "$day" -gt 1 ] && ELAPSED_TIME="$day days"
        [ "$day" = 1 ] && ELAPSED_TIME="$day day"
        [ "$ELAPSED_TIME" != "" ] && comma=", "
        [ "$hr" -gt 1 ] && ELAPSED_TIME="$ELAPSED_TIME$comma$hr hrs"
        [ "$hr" = 1 ] && ELAPSED_TIME="$ELAPSED_TIME$comma$hr hr"
        [ "$ELAPSED_TIME" != "" ] && comma=", "
        [ "$min" -gt 1 ] && ELAPSED_TIME="$ELAPSED_TIME$comma$min mins"
        [ "$min" = 1 ] && ELAPSED_TIME="$ELAPSED_TIME$comma$min min"
    fi
}
output_file() {
    cat << ENDHTML
          <TR><TD width="160">Output</TD><TD width="300">$OUTPUT</TD></TR>
ENDHTML
    FILE=/var/run/net_out1.conf
    [ ! -f $FILE ] && FILE=/var/run/net_out2.conf
    if [ -f $FILE ] ; then
        . $FILE
        [ "$MOUNT_DIR" != "" ] && file_info
    fi
}

file_info() {
    tmp_file=/tmp/tmp.$$
    if [ "$MOUNT_DIR" = /net_drive ] ; then
        FILE_LABEL="Remote Directory"
        df -h $MOUNT_DIR | awk -f /qvidium/df_out.awk > $tmp_file
    else
        FILE_LABEL=USB
        df -h $MOUNT_DIR | grep /dev/sd > $tmp_file
    fi
    read dummy FILE_SIZE USED AVAVILABLE PERCENT dummy2 < $tmp_file
    CLIP=`echo ${CLIP_FILENAME} | sed 's/\./\*\./'`
    ls -lh $MOUNT_DIR/${CLIP} | tail -1 > $tmp_file
    read d1 d2 d3 d4 CLIP_SIZE MON DAY TM_YR d5 < $tmp_file
    CLIP_FILENAME=`basename $d5`
    cat << ENDHTML
          <tr align=center><td colSpan="2" nowrap><strong><font size="4">Clip</font></strong></td></tr>
          <TR><TD width="160">Name</TD><TD width="300">$CLIP_FILENAME</TD></TR>
          <TR><TD width="160">Size</TD><TD width="300">$CLIP_SIZE</TD></TR>
          <!--
          <TR><TD width="160">Date</TD><TD width="300">$MON $DAY $TM_YR</TD></TR>
          -->
          <tr align=center><td colSpan="2" nowrap><strong><font size="4">$FILE_LABEL Usage</font></strong></td></tr>
          <TR><TD width="160">Size</TD><TD width="300">$FILE_SIZE</TD></TR>
          <TR><TD width="160">Used</TD><TD width="300">$USED</TD></TR>
          <TR><TD width="160">Available</TD><TD width="300">$AVAVILABLE</TD></TR>
          <TR><TD width="160">Percent Used</TD><TD width="300">$PERCENT</TD></TR>
ENDHTML
    rm -f $tmp_file
}

HAS_RTMP=0
[ -f /disk/evostream/startup ] && HAS_RTMP=1

case "$SCRIPT_NAME" in
  *2*) NUM=2 ;;
    *) NUM=1 ;;
esac

monitor=false
if [ "$QUERY_STRING" = m ] ; then
    monitor=true
elif [ "$QUERY_STRING"x != x ] ; then
    eval `./cgiparse "$QUERY_STRING"`
    [ "$m"x != x ] && monitor=true
fi

if [ "$TEXT_OUTPUT" = true ] ; then
    cat << ENDHTML
Content-type: text/plain

ENDHTML
else
    # Print common header
    cat << ENDHTML
Content-type: text/html

<HTML>
<HEAD>
<LINK rel="stylesheet" href="/style.css" type="text/css">
<TITLE>Encoder $NUM Status</TITLE>
ENDHTML
fi

pidof encoder$NUM > /dev/null
if [ $? != 0 ] ; then
    if [ "$TEXT_OUTPUT" = true ] ; then
        echo "Not sending to network."
    else
        cat << ENDHTML
</HEAD>
<BODY>
<h3>Encoder $NUM Status</h3>
Encoder $NUM is not running.<br>
<p>Not sending to network.</p>
</BODY>
</HTML>
ENDHTML
    fi
    exit 0
fi

STATUS_FILE=/var/run/net_out$NUM.status
# Read in current stats from *.status in /var/run
#if [ -f $STATUS_FILE ] ; then

    if [ "$TEXT_OUTPUT" = true ] ; then
        STARTED=`cat /var/run/net_out$NUM.start`
        STATS_CLEARED=`cat /var/run/net_out$NUM.stats`
        TRANSPORT=UDP
        CONF_FILE=/flash/qvidium/net_out$NUM.conf
        [ -f $CONF_FILE ] && . $CONF_FILE
        CURRENT_TIME=`date +"%b %d %T"`
        cat <<!
PROFILE_NAME="$NAME"
CURRENT_TIME="$CURRENT_TIME"
STARTED="$STARTED"
STATS_CLEARED="$STATS_CLEARED"
TRANSPORT="$TRANSPORT"
IPADDR_OR_HOSTNAME="$IPADDR_OR_HOSTNAME"
UDP_PORT="$UDP_PORT"
ARQ_PORT="$ARQ_PORT"
SERVICE_NAME="$SERVICE_NAME"
!

        HAS_SDI=false
        [ -f /flash/qvidium/inputs.conf ] && . /flash/qvidium/inputs.conf
        [ "$HAS_SDI" = "" ] && HAS_SDI=false

        if [ "$HAS_SDI" == false ] ; then
            echo "SDI_INPUT="
        else
            TMP_FILE=/tmp/out$$
            sdidiag > $TMP_FILE 2>&1
            if grep 'No Video Sync' $TMP_FILE > /dev/null ; then
                echo 'SDI_INPUT="No Video Sync"'
            else
                echo "SDI_INPUT=`awk '/CEA-861 Video Format:/ {print $4}' $TMP_FILE`"
            fi
            rm -f $TMP_FILE
        fi
        [ -f $STATUS_FILE ] && grep '[A-Z].*=' $STATUS_FILE
        exit 0
    fi

    if [ $monitor = true ] ; then
        cat << ENDHTML
<SCRIPT LANGUAGE=JAVASCRIPT>

  function RefreshPage()
  {
     window.location.reload(true);
  }

  function StartTimer()
  {
     window.setTimeout("RefreshPage()", 3000);
  }

</SCRIPT>
</HEAD>
<BODY onload="StartTimer();">
ENDHTML
    else
        cat << ENDHTML
</HEAD>
<BODY>
ENDHTML
    fi
    cat << ENDHTML
ENDHTML

    STARTED=`cat /var/run/net_out$NUM.start`
    STATS_CLEARED=`cat /var/run/net_out$NUM.stats`

    CURRENT_TIME=`date +'%b %d %T'`
    DATE2=`date +%s`

    DATE1=`date -d "$STATS_CLEARED" -D '%b %d %T' +%s`
    SECS=$((DATE2 - DATE1))
    get_elapsed_time $SECS
    CLEARED_TIME="$ELAPSED_TIME"

    DATE1=`date -d "$STARTED" -D '%b %d %T' +%s`
    SECS=$((DATE2 - DATE1))
    get_elapsed_time $SECS

    TRANSPORT=UDP
    CONF_FILE=/flash/qvidium/net_out$NUM.conf
    [ -f $CONF_FILE ] && . $CONF_FILE

    [ -f $STATUS_FILE ] && eval `grep '[A-Z].*=' $STATUS_FILE`

    if [ "$OUTPUT" = 'File TS' -o "$OUTPUT" = 'File MP4' ] ; then
        true
    else
        [ $HAS_RTMP = 1 -a "$TRANSPORT" = RTMP ] && OUTPUT=Network
    fi

    cat << ENDHTML
        <TABLE class=props>
          <tr align=left><th colSpan="2" nowrap>Stream</th></tr>
          <TR><TD width="160">Profile</TD><TD width="300">$NAME</TD></TR>
          <TR><TD width="160">Current Time</TD><TD width="300">$CURRENT_TIME</TD></TR>
          <TR><TD width="160">Started</TD><TD width="300">$STARTED</TD></TR>
          <TR><TD width="160">Elasped Time</TD><TD width="300">$ELAPSED_TIME</TD></TR>
ENDHTML
    if [ "$OUTPUT" = ASI ] ; then
        cat << ENDHTML
          <TR><TD width="160">Output</TD><TD width="300">$OUTPUT</TD></TR>
ENDHTML
    elif [ "$OUTPUT" = 'File TS' -o "$OUTPUT" = 'File MP4' ] ; then
        output_file
        TRANSPORT=UDP
    else
      cat << ENDHTML
          <TR><TD width="160">Stats Cleared</TD><TD width="300">$CLEARED_TIME ago</TD></TR>
ENDHTML
      [ "$OUTPUT" = "Network + File" ] && output_file
      cat << ENDHTML
        </TABLE>
        <TABLE class=props>
          <tr align=left><th colSpan="2" nowrap>Network</th></tr>
          <TR><TD width="160">Transport</TD><TD width="300">$TRANSPORT</TD></TR>
          <TR><TD width="160">Bitrate</TD><TD width="300">$NET_BITRATE</TD></TR>
          <TR><TD width="160">Total Packets</TD><TD width="300">$NET_TOTAL_PACKETS</TD></TR>
ENDHTML
    fi
    if [ "$TRANSPORT" = ARQ -a "$OUTPUT" != ASI ] ; then
        eval `/qvidium/tx_proxy_request 127.0.0.1 654`
        DELAY=$(((ARQ_DELAY / 2) + (ARQ_NUM_RETRIES * ARQ_RTT)))
        cat << ENDHTML
          </TABLE>
          <TABLE class=props>
           <tr align=left><th colSpan="2" nowrap>QVidium ARQ</th></tr>
           <TR><TD width="160">Resent</TD><TD width="300">$ARQ_RESENT</TD></TR>
           <TR><TD width="160">Missing</TD><TD width="300">$ARQ_MISS</TD></TR>
           <TR><TD width="160">Max Burst Loss</TD><TD width="300">$ARQ_MAXBURSTLOSS</TD></TR>
           <TR><TD width="160">Stale Requests</TD><TD width="300">$ARQ_STALE</TD></TR>
           <TR><TD width="160">Ignored Requests</TD><TD width="300">$ARQ_IGNORED</TD></TR>
           <TR><TD width="160">Latency</TD><TD width="300">$DELAY</TD></TR>
           <TR><TD width="160">Number Retries</TD><TD width="300">$ARQ_NUM_RETRIES</TD></TR>
           <TR><TD width="160">Round Trip Time</TD><TD width="300">$ARQ_RTT</TD></TR>
           <TR><TD width="160">Clients</TD><TD width="300">$CLIENTS</TD></TR>
ENDHTML
    elif  [ "$TRANSPORT" = Zixi -a "$OUTPUT" != ASI ] ; then
        eval `/qvidium/tx_proxy_request 127.0.0.1 600`
		ZIXI_STATS=/var/run/ZixiTx.status
		if [ -f $ZIXI_STATS ] ; then
			. $ZIXI_STATS
		fi
        cat << ENDHTML
          </TABLE>
          <TABLE class=props>
           <tr align=left><th colSpan="2" nowrap>Zixi ARQ</th></tr>
           <TR><TD width="160">Resent</TD><TD width="300">$ARQ_RESENT</TD></TR>
           <TR><TD width="160">Dropped</TD><TD width="300">$ARQ_DROPPED</TD></TR>
           <TR><TD width="160">Missing</TD><TD width="300">$ARQ_MISS</TD></TR>
           <TR><TD width="160">Stale Requests</TD><TD width="300">$ARQ_STALE</TD></TR>
           <TR><TD width="160">Ignored Requests</TD><TD width="300">$ARQ_IGNORED</TD></TR>
           <TR><TD width="160">Latency</TD><TD width="300">$ARQ_DELAY</TD></TR>
           <TR><TD width="160">Round Trip Time</TD><TD width="300">$ARQ_RTT</TD></TR>
           <TR><TD width="160">Clients</TD><TD width="300">$CLIENTS</TD></TR>
ENDHTML
    fi

    echo "</TABLE>"

#else
#    cat << ENDHTML
#</HEAD>
#<BODY>
#<P align="center"><STRONG>
#<FONT size="5">Encoder Status</P>
#<P align="left"></FONT></STRONG>
#<p><FONT size=4>No network send stats available.</P>
#ENDHTML
#fi

if [ 1 = 2 -a  "$MOUNT_DIR" != "" ] ; then
    tmp_file=/tmp/tmp.$$
    cat << ENDHTML
        <br>Other Files/Folder on USB File System (sorted by Date)
        <TABLE class=props cellSpacing="1" cellPadding="2" border="1">
         <TR>
          <TH>Name</TH>
          <TH>Size</TH>
          <TH>Type</TH>
          <TH>Date Modified</TH>
         </TR>
ENDHTML
    ls -lth $MOUNT_DIR | egrep -v $CLIP_FILENAME'|^total' > $tmp_file
    while read PERM d1 d2 d3 SIZE MON DAY TM_YR NAME
    do
        TYPE=File
        case "$PERM" in
            d*) TYPE=Folder ;;
        esac
    cat << ENDHTML
         <TR>
          <TD>$NAME</TD>
          <TD>$SIZE</TD>
          <TD>$TYPE</TD>
          <TD>$MON $DAY $TM_YR</TD>
         </TR>
ENDHTML
    done < $tmp_file
    echo "</TABLE>"
    rm -f $tmp_file
fi

cat << ENDHTML
</BODY>
</HTML>
ENDHTML

exit 0
